package pcrc

  1. Overview
  2. Docs

Module CRC8.DVB_S2Source

ETSI EN 302 307-1 version 1.4.1 (November 2014). ETSI EN 302 755 version 1.4.1 (July 2015). Ethernet POWERLINK Standardisation Group (18 October 2018), OpenSAFETY Safety Profile Specification Working Draft Proposal, version 1.5.2.

Sourceval rev : bool

Whether input bytes and the final CRC value are reflected by the implementation. The corresponding parameters in the CRC model are "REFIN" and "REFOUT".

Sourceval poly : t

The polynomial of the CRC implementation. Always in direct/normal notation, regardless of the rev parameter. Corresponds to the "POLY" parameter in the model.

Sourceval init : t

Initial value of the CRC register. Always in direct/normal notation, regardless of the rev parameter. Corresponds to the "INIT" parameter of the CRC model.

Sourceval final : t

The value to be XORed to the final register value before returning the CRC. Corresponds to the "XOROUT" parameter in the CRC model.